/* Copyright (C) 2024 GSI Helmholtzzentrum fuer Schwerionenforschung, Darmstadt
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Pierre-Alain Loizeau [committer], Felix Weiglhofer, Dominik Smith */
#pragma once

#include "Definitions.h"

#include <vector>

namespace cbm::algo::bmon::config
{

  struct CROB {
    i32 moduleId;
    i32 rpcType;
    i32 rpcSide;
    i32 nRPC;
  };

  struct ReadoutPars {

    static ReadoutPars MakeMCBM2022();
    static ReadoutPars MakeMCBM2024();

    i32 nFebsPerComponent;
    i32 nAsicsPerFeb;
    i32 nChannelsPerAsic;
    i32 nCrobPerComponent;

    std::vector<CROB> crobs;
    size_t NCROBs() const { return crobs.size(); }

    // Array to hold the unique IDs (equipment ID) for all TOF DPBs
    std::vector<u16> eqIds;
    size_t NComponents() const { return eqIds.size(); }

    i32 NFebsPerCrob() const { return nFebsPerComponent / nCrobPerComponent; }
    i32 NChansPerFeb() const { return nAsicsPerFeb * nChannelsPerAsic; }
    i32 NChansPerComponent() const { return nChannelsPerAsic * NElinksPerComponent(); }
    i32 NElinksPerCrob() const { return nAsicsPerFeb * NFebsPerCrob(); }
    i32 NElinksPerComponent() const { return NElinksPerCrob() * nCrobPerComponent; }

    bool CheckBmonComp(uint32_t uCompId) const { return ((uCompId & 0xFFF0) == 0xABF0); }
    bool CheckInnerComp(uint32_t uCompId) const { return ((uCompId & 0xFFF0) == 0xBBC0); }
  };

}  // namespace cbm::algo::bmon::config
