/* Copyright (C) 2024 GSI Helmholtzzentrum fuer Schwerionenforschung, Darmstadt
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Felix Weiglhofer [committer], Dominik Smith */
#pragma once

#include "Definitions.h"

#include <vector>

namespace cbm::algo::tof::config
{

  struct CROB {
    i32 moduleId;
    i32 rpcType;
    i32 rpcSide;
    i32 nRPC;
  };

  struct ReadoutPars {

    static ReadoutPars MakeMCBM2022();
    static ReadoutPars MakeMCBM2024();
    static ReadoutPars MakeMCBM2024_05();

    bool mcbmTof2024 = false;

    i32 nFebsPerComponent;
    i32 nAsicsPerFeb;
    i32 nChannelsPerAsic;
    i32 nCrobPerComponent;

    std::vector<CROB> crobs;
    size_t NCROBs() const { return crobs.size(); }

    // Array to hold the unique IDs (equipment ID) for all TOF DPBs
    std::vector<u16> eqIds;
    size_t NComponents() const { return eqIds.size(); }


    // Mapping to eLink to ASIC number within CROB. Mapping is the same for each CROB. (size: nElinksPerCrob)
    std::vector<i32> elink2Asic;
    std::vector<i32> elink2AsicInner;

    // Mapping in Readout chain PCBs
    // Map from GET4 channel to PADI channel
    // (size: nChansPerFeb)
    std::vector<i32> asic2PadI;

    i32 NFebsPerCrob() const { return nFebsPerComponent / nCrobPerComponent; }
    i32 NChansPerFeb() const { return nAsicsPerFeb * nChannelsPerAsic; }
    i32 NChansPerComponent() const { return nChannelsPerAsic * NElinksPerComponent(); }
    i32 NElinksPerCrob() const { return nAsicsPerFeb * NFebsPerCrob(); }
    i32 NElinksPerComponent() const { return NElinksPerCrob() * nCrobPerComponent; }

    bool CheckBmonComp(uint32_t uCompId) const { return ((uCompId & 0xFFF0) == 0xABF0); }
    bool CheckInnerComp(uint32_t uCompId) const { return ((uCompId & 0xFFF0) == 0xBBC0); }
  };

}  // namespace cbm::algo::tof::config
