#!/bin/bash
# Copyright (C) 2024 GSI Helmholtzzentrum fuer Schwerionenforschung, Darmstadt
# SPDX-License-Identifier: GPL-3.0-only
# First commited by Pierre-Alain Loizeau

WAS_MCBM_MODE=0
START_DIR=$PWD

# I: switch of branch/commit. Done only after all checks to avoid Geometry and Parameter folder going out of sync
#     (one in "Official detached commit" and the other on "mCBM repo HEAD" mode)
# I-A: Geometry folder
# I-A-1) Go to folder
cd ${VMCWORKDIR}/geometry
# I-A-2) Check if current version is the Official detached commit or the mCBM repo HEAD
if [[ 1 -eq $(git status | grep -c "HEAD detached at") ]]; then
  echo "Geometry folder already in official version, no need to switch back"
else
  WAS_MCBM_MODE=1
  if ! ${VMCWORKDIR}/macro/beamtime/mcbm2024/switch_geo_par.sh; then
    echo "Failed switching the geometry and parameters folders back to the official version, stopping there"
    exit 1
  fi
fi
# I-B: parameters folder
# I-B-1) Go to folder
cd ${VMCWORKDIR}/parameters
# I-B-2) Check if current version is the Official detached commit or the mCBM repo HEAD
if [[ 1 -eq $(git status | grep -c "HEAD detached at") ]]; then
  echo "Parameters folder already in official version, no need to switch back"
else
  echo "Check on geometry folder should have already reverted the parameters one but still in mCBM mode"
  echo "Please check your local folders with git status, your copy may be brocken/have folders out of sync"
  exit 2
fi

cd $START_DIR

# II: Cbmroot update in the standard way,
#     => assumes in the source root folder but should anyway work anywhere in the tree
#     => assumes that the official repo remote is already defined (e.g. either as origin or upstream)
official=$(git remote -v | grep fetch | grep "computing/cbmroot.git" | cut -f1)
if [ -n "${official}" ]; then
  # Depending on your remote settings, the next command may ask for login/password information
  git fetch ${official}
  git rebase ${official}/master
else
  echo "No remote found pointing to the official cbmroot repository/fork, rebase will not be done!!!!"
fi

# III: revert geometry and parameters folders to mCBM mode if was the case before this call
if [[ 1 -eq ${WAS_MCBM_MODE} ]]; then
  ${VMCWORKDIR}/macro/beamtime/mcbm2024/switch_geo_par.sh
fi

exit 0
