/* Copyright (C) 2023 GSI Helmholtzzentrum fuer Schwerionenforschung, Darmstadt
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Sergei Zharko [committer] */

/// \file   CbmCaInputQaMvd.h
/// \date   10.09.2023
/// \brief  QA-task for CA tracking input from MVD (header)
/// \author S.Zharko <s.zharko@gsi.de>


#pragma once

#include "CbmCaInputQaBase.h"

/// A QA-task class, which provides assurance of TOF hits and geometry
///
class CbmCaInputQaMvd : public CbmCaInputQaBase<cbm::algo::ca::EDetectorID::kMvd> {
 public:
  /// @brief  Constructor from parameters
  /// @param  verbose   Verbose level
  /// @param  isMCUsed  Flag, whether MC information is available for this task
  CbmCaInputQaMvd(int verbose, bool isMCUsed);

 protected:
  /// \brief  Method to check, if the QA results are acceptable
  void Check() override { return CbmCaInputQaBase::Check(); }

  /// @brief Initializes data branches
  InitStatus InitDataBranches() override;

  /// @brief Initializes canvases
  InitStatus InitCanvases() override;

  /// @brief Initializes histograms
  InitStatus InitHistograms() override;

  /// @brief Fills histograms per event or time-slice
  void FillHistograms() override { CbmCaInputQaBase::FillHistograms(); }

  /// @brief De-initializes histograms
  void DeInit() override;

  /// @brief Defines parameters of the task
  void DefineParameters() override;

  /// @brief Fills histograms per hit
  void FillHistogramsPerHit() override;

  /// @brief Fills histograms per MC point
  void FillHistogramsPerPoint() override {}

 private:
  ClassDefOverride(CbmCaInputQaMvd, 0);
};
