/* Copyright (C) 2024 Hulubei National Institute of Physics and Nuclear Engineering - Horia Hulubei, Bucharest
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Alexandru Bercuci [committer] */

#ifndef CBMRECOQATASK_H
#define CBMRECOQATASK_H 1

#include "CbmKfTrackFitter.h"
// #include "CbmQaHist.h"

#include "FairTask.h"
#include "TFolder.h"

#include <map>
#include <vector>

class CbmTimeSlice;
class TClonesArray;
class TH2D;
class CbmRecoQaTask : public FairTask {
 public:
  enum Setup
  {
    kMcbm22 = 0,
    kMcbm24,
    kDefault
  };

 public:
  CbmRecoQaTask();
  virtual ~CbmRecoQaTask() { ; }

  virtual InitStatus Init();
  /** \brief Executed task **/
  virtual void Exec(Option_t* option);

  /** \brief Filter tracks for further use (e.g. track projections) 
   * \param[in] ptr information on which to filter (e.g. nhits from detectors)
   * \return true if track accepted
   */
  virtual bool FilterTrack(int* ptr);
  virtual void Finish();

  /** \brief Define the set of extra z positions where the track should be projected in the x-y plane */
  void SetProjections(std::vector<double> vzpj);
  void SetSetupClass(CbmRecoQaTask::Setup setup) { fSetupClass = setup; }

 private:
  CbmRecoQaTask(const CbmRecoQaTask&);
  CbmRecoQaTask& operator=(const CbmRecoQaTask&);

  struct ModuleView {
    std::pair<float, TH2D*> hdXx = std::make_pair(1, nullptr);
    std::pair<float, TH2D*> hdYy = std::make_pair(1, nullptr);
    std::pair<float, TH2D*> hdT  = std::make_pair(1, nullptr);
    TH2D* hpullXphi              = nullptr;
    TH2D* hpullYtht              = nullptr;
  };
  CbmKfTrackFitter fFitter;
  TClonesArray* fTracks       = nullptr;  //! reconstructed global tracks / event
  TClonesArray* fTrackMatches = nullptr;  //! MC info for the global tracks
  TClonesArray* fEvents       = nullptr;  //! reconstructed events
  CbmTimeSlice* fTimeSlice    = nullptr;  //! Time slice info
  //
  TFolder fOutFolder                              = {"RecoQA", "CA track driven reco QA"};  //!
  Setup fSetupClass                               = Setup::kMcbm22;
  std::map<int, std::vector<ModuleView>> fModView = {};  //!
  std::map<double, TH2D*> fProjView               = {};  //!

  ClassDef(CbmRecoQaTask, 1);  // Reconstruction QA analyzed from CA perspective
};

#endif  // CBMRECOQATASK_H
